// based on https://deno.land/x/cache@0.2.13
import { Path } from "./deps.node.js";
const POSIX_HOME = "HOME";
export function getCacheDir() {
    const env = Deno.env.get;
    const os = Deno.build.os;
    const deno = env("DENO_DIR");
    if (deno)
        return deno;
    let home;
    let path;
    switch (os) {
        case "linux": {
            const xdg = env("XDG_CACHE_HOME");
            home = xdg ?? env(POSIX_HOME);
            path = xdg ? "deno" : ".cache/deno/";
            break;
        }
        case "darwin":
            home = env(POSIX_HOME);
            path = "Library/Caches/deno/";
            break;
        case "windows":
            home = env("LOCALAPPDATA") ?? env("USERPROFILE");
            path = "deno";
            break;
        default:
            throw new Error(`Unsupported OS: ${os}`);
    }
    if (!home)
        return ".deno";
    return Path.resolve(home, path);
}
import { Deno } from "./shim.node.js";
