export declare class CacheEntry {
    /** Input URL */
    readonly url: Readonly<URL>;
    readonly hash: string;
    /** Path where the response body is (or would be) cached. */
    readonly path: string;
    /** Path where the compiled JS is (or would be) cached. */
    readonly jsPath: string;
    /**
     * Calculates where a gives URL is (or would be) cached.
     * Performs no IO.
     * @permissions `--allow-env`
     */
    constructor(url: string | URL);
    /** Path where the response headers are (or would be) cached. */
    get metaPath(): string;
    /**
     * @permissions `--allow-read`
     * @returns cached `Response` on success.
     * @throws `Deno.errors.NotFound` when the URL isn't cached.
     */
    read(options?: Deno.ReadFileOptions): Promise<Response>;
    /**
     * Stores the response in cache.
     * @permissions `--allow-write`
     */
    write(res: Response): Promise<void>;
}
import { Response, Deno } from "./shim.node.js";
//# sourceMappingURL=entry.d.ts.map